@@ -11,9 +11,9 @@ use File::chdir;
 use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-31'; # DATE
+our $DATE = '2023-11-02'; # DATE
 our $DIST = 'App-FileSortUtils'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our %SPEC;
 
@@ -39,6 +39,24 @@ our %argspecs_common = (
         },
         tags => ['category:filtering'],
     },
+    exclude_filename_pattern => {
+        summary => 'Exclude filenames that match a regex pattern',
+        schema => 're_from_str*',
+        cmdline_aliases => {X=>{}},
+        tags => ['category:filtering'],
+    },
+    include_filename_pattern => {
+        summary => 'Only include filenames that match a regex pattern',
+        schema => 're_from_str*',
+        cmdline_aliases => {I=>{}},
+        tags => ['category:filtering'],
+    },
+    all => {
+        summary => 'Do not ignore entries starting with .',
+        schema => 'true*',
+        cmdline_aliases => {a=>{}},
+        tags => ['category:filtering'],
+    },
 
     detail => {
         schema => 'true*',
@@ -149,6 +167,7 @@ MARKDOWN
 };
 sub sort_files {
     my %args = @_;
+    my $all = $args{all} // 0;
 
     my $dir = $args{dir} // '.';
     opendir my $dh, $dir or return [500, "Can't opendir '$dir': $!"];
@@ -158,6 +177,24 @@ sub sort_files {
       FILE:
         while (defined(my $e = readdir $dh)) {
             next if $e eq '.' || $e eq '..';
+            if (defined $args{include_filename_pattern}) {
+                unless ($e =~ $args{include_filename_pattern}) {
+                    log_trace "File $e excluded (not match $args{include_filename_pattern})";
+                    next FILE;
+                }
+            }
+            if (defined $args{exclude_filename_pattern}) {
+                if ($e =~ $args{exclude_filename_pattern}) {
+                    log_trace "File $e excluded (matches $args{exclude_filename_pattern})";
+                    next FILE;
+                }
+            }
+            if (!$all) {
+                if ($e =~ /\A\./) {
+                    log_trace "File $e excluded (dotfile hidden)";
+                    next FILE;
+                }
+            }
             my $rec = {name=>$e};
             my @st = lstat $e or do {
                 warn "Can't stat '$e' in '$dir': $!, skipped";
@@ -299,6 +336,9 @@ gen_modified_sub(
     summary => 'Return file(s) which are alphabetically the first',
     description => <<'MARKDOWN',
 
+Notes:
+- by default dotfiles are not included, use `--all` (`-a`) to include them
+
 Some examples:
 
     # return foremost file in current directory
@@ -332,6 +372,9 @@ gen_modified_sub(
     summary => 'Return file(s) which are alphabetically the last',
     description => <<'MARKDOWN',
 
+Notes:
+- by default dotfiles are not included, use `--all` (`-a`) to include them
+
 Some examples:
 
     # return hindmost file in current directory
@@ -430,6 +473,9 @@ gen_modified_sub(
     summary => 'Return the newest file(s) in a directory',
     description => <<'MARKDOWN',
 
+Notes:
+- by default dotfiles are not included, use `--all` (`-a`) to include them
+
 Suppose a new file is downloaded in `~/Downloads`, but you are not sure of its
 name. You just want to move that file, which you are pretty sure is the newest
 in the `Downloads` directory, somewhere else. So from the CLI in `~/Downloads`:
@@ -480,6 +526,9 @@ gen_modified_sub(
     summary => 'Return the oldest file(s) in a directory',
     description => <<'MARKDOWN',
 
+Notes:
+- by default dotfiles are not included, use `--all` (`-a`) to include them
+
 File is deemed as oldest by its mtime.
 
 Some examples:
@@ -515,6 +564,9 @@ gen_modified_sub(
     summary => 'Return file(s) with the longest name in a directory',
     description => <<'MARKDOWN',
 
+Notes:
+- by default dotfiles are not included, use `--all` (`-a`) to include them
+
 Some examples:
 
     # return file with the longest name in current directory
@@ -548,6 +600,9 @@ gen_modified_sub(
     summary => 'Return file(s) with the shortest name in a directory',
     description => <<'MARKDOWN',
 
+Notes:
+- by default dotfiles are not included, use `--all` (`-a`) to include them
+
 Some examples:
 
     # return file with the shortest name in current directory
@@ -587,7 +642,7 @@ App::FileSortUtils - Utilities related to sorting files in a directory
 
 =head1 VERSION
 
-This document describes version 0.005 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-10-31.
+This document describes version 0.006 of App::FileSortUtils (from Perl distribution App-FileSortUtils), released on 2023-11-02.
 
 =head1 DESCRIPTION
 
@@ -626,6 +681,9 @@ Usage:
 
 Return file(s) which are alphabetically the first.
 
+Notes:
+- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
 Some examples:
 
  # return foremost file in current directory
@@ -637,6 +695,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -645,10 +707,18 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
 =item * B<ignore_case> => I<bool>
 
 (No description)
 
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -692,6 +762,9 @@ Usage:
 
 Return file(s) which are alphabetically the last.
 
+Notes:
+- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
 Some examples:
 
  # return hindmost file in current directory
@@ -703,6 +776,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -711,10 +788,18 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
 =item * B<ignore_case> => I<bool>
 
 (No description)
 
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -773,6 +858,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -781,6 +870,14 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -824,6 +921,9 @@ Usage:
 
 Return file(s) with the longest name in a directory.
 
+Notes:
+- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
 Some examples:
 
  # return file with the longest name in current directory
@@ -839,6 +939,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -847,6 +951,14 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -890,6 +1002,9 @@ Usage:
 
 Return the newest file(s) in a directory.
 
+Notes:
+- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
 Suppose a new file is downloaded in C<~/Downloads>, but you are not sure of its
 name. You just want to move that file, which you are pretty sure is the newest
 in the C<Downloads> directory, somewhere else. So from the CLI in C<~/Downloads>:
@@ -921,6 +1036,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -929,6 +1048,14 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -972,6 +1099,9 @@ Usage:
 
 Return the oldest file(s) in a directory.
 
+Notes:
+- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
 File is deemed as oldest by its mtime.
 
 Some examples:
@@ -989,6 +1119,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -997,6 +1131,14 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -1040,6 +1182,9 @@ Usage:
 
 Return file(s) with the shortest name in a directory.
 
+Notes:
+- by default dotfiles are not included, use C<--all> (C<-a>) to include them
+
 Some examples:
 
  # return file with the shortest name in current directory
@@ -1055,6 +1200,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -1063,6 +1212,14 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -1121,6 +1278,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<detail> => I<true>
 
 (No description)
@@ -1129,6 +1290,14 @@ Arguments ('*' denotes required arguments):
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<num_ranks> => I<uint>
 
 Number of ranks to return.
@@ -1178,6 +1347,10 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<all> => I<true>
+
+Do not ignore entries starting with .
+
 =item * B<by_code> => I<code_from_str>
 
 Perl code to sort.
@@ -1198,6 +1371,14 @@ Sort::Sub routine name to sort.
 
 Directory to sort files of, defaults to current directory.
 
+=item * B<exclude_filename_pattern> => I<re_from_str>
+
+Exclude filenames that match a regex pattern.
+
+=item * B<include_filename_pattern> => I<re_from_str>
+
+Only include filenames that match a regex pattern.
+
 =item * B<key> => I<code_from_str>
 
 Perl code to generate key to sort against.
